Numina, the data reduction package 
==================================

Primary authors:

 * Sergio Pascual <sergiopr@fis.ucm.es>
 * Nicolas Cardiel <cardiel@fis.ucm.es>
 * Pablo Picazo <papicazo@ucm.es>

